CommandEntry class

Represents a command exposed through the palette.

Provide a stable id, a human-friendly title, and an optional subtitle (displayed dimmed to the right of the title).

Constructors

CommandEntry({required String id, required String title, String? subtitle})
Creates a new CommandEntry.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
A unique identifier for this command.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
Optional secondary text displayed dimmed next to the title.
final
title String
The primary text displayed for this command.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited