FlowContext class

Read-only view of values collected by earlier flow steps.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
terminice Terminice
Terminice instance configured for the current flow.
no setter

Methods

contains(String key) bool
Whether key has been written by the flow.
inherited
fallbackPromptTitle(String title) String
Returns the plain title for fallback or basic prompt text.
flag(String key) bool
Returns the boolean flag stored for key.
inherited
list<T>(String key) List<T>
Returns the list stored for key as List<T>.
inherited
maybe<T>(String key) → T?
Returns the value stored for key as T, or null when absent or null.
inherited
maybeFlag(String key) bool?
Returns the boolean flag stored for key, or null when absent or null.
inherited
maybeString(String key) String?
Returns the string stored for key, or null when absent or null.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
promptTitle(String title) String
Returns title decorated with the current flow progress when enabled.
runComponent<T>(TerminiceComponent<T> component) → T
Runs component with the Terminice instance configured for this flow.
string(String key) String
Returns the string stored for key.
inherited
toMap() Map<String, Object?>
Returns an insertion-ordered copy of the visible values.
inherited
toString() String
A string representation of this object.
inherited
value<T>(String key) → T
Returns the value stored for key as T.
inherited
valueOr<T>(String key, T fallback) → T
Returns the value stored for key as T, or fallback when absent/null.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited