flag method
Returns the boolean flag stored for key.
Throws a StateError when key is missing or is not a bool.
Implementation
bool flag(String key) => value<bool>(key);
Returns the boolean flag stored for key.
Throws a StateError when key is missing or is not a bool.
bool flag(String key) => value<bool>(key);