list<T> method
Returns the list stored for key as List<T>.
Throws a StateError when key is missing or is not a List<T>.
Implementation
List<T> list<T>(String key) => value<List<T>>(key);
Returns the list stored for key as List<T>.
Throws a StateError when key is missing or is not a List<T>.
List<T> list<T>(String key) => value<List<T>>(key);