runComponent<T> method
Runs component with the Terminice instance configured for this flow.
Implementation
T runComponent<T>(TerminiceComponent<T> component) {
return _terminice.runComponent<T>(component);
}
Runs component with the Terminice instance configured for this flow.
T runComponent<T>(TerminiceComponent<T> component) {
return _terminice.runComponent<T>(component);
}