FlowResult class

Result returned after a flow confirms or cancels.

Properties

cancelled bool
Whether the flow stopped because a step cancelled.
no setter
cancelledKey String?
Key of the step that cancelled the flow, if any.
final
confirmed bool
Whether the flow ran all applicable steps without cancellation.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(String key) bool
Whether key has been written by the flow.
inherited
flag(String key) bool
Returns the boolean flag stored for key.
inherited
list<T>(String key) List<T>
Returns the list stored for key as List<T>.
inherited
maybe<T>(String key) → T?
Returns the value stored for key as T, or null when absent or null.
inherited
maybeFlag(String key) bool?
Returns the boolean flag stored for key, or null when absent or null.
inherited
maybeString(String key) String?
Returns the string stored for key, or null when absent or null.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
string(String key) String
Returns the string stored for key.
inherited
toMap() Map<String, Object?>
Returns an insertion-ordered copy of the visible values.
inherited
toString() String
A string representation of this object.
inherited
value<T>(String key) → T
Returns the value stored for key as T.
inherited
valueOr<T>(String key, T fallback) → T
Returns the value stored for key as T, or fallback when absent/null.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited