loadingSpinner method

LoadingSpinner loadingSpinner(
  1. String prompt, {
  2. String message = 'Loading',
  3. SpinnerStyle style = SpinnerStyle.dots,
})

Creates a themed loading spinner with customizable message and style.

final spinner = terminice.loadingSpinner('Loading');
spinner.show(0);
// ... do work ...
spinner.show(1);
spinner.clear();

The prompt is the label displayed above the spinner. The message is the text displayed next to the spinner. The style determines the visual appearance of the spinner.

Implementation

LoadingSpinner loadingSpinner(
  String prompt, {
  String message = 'Loading',
  SpinnerStyle style = SpinnerStyle.dots,
}) {
  return LoadingSpinner._fromTerminice(
    prompt,
    this,
    message: message,
    style: style,
    theme: defaultTheme,
  );
}