PathPickerExtensions extension
Adds the pathPicker method to Terminice for interactive directory and file selection.
- on
Methods
-
pathPicker(
String prompt, {Directory? startDirectory, bool showHidden = false, bool allowFiles = false, int maxVisible = 18}) → String? -
Available on Terminice, provided by the PathPickerExtensions extension
Launches the dynamic path picker for selecting directories (and optional files).