RangeValue class
Internal pair to hold the two endpoints of a range.
Constructors
- RangeValue(num start, num end)
-
Creates a new RangeValue with the given
startandend.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override