SpinnerStyle enum

Available visual styles for spinners and shimmer effects.

  • dots: Braille-inspired glyphs with fluid motion.
  • bars: Rising bar graph that loops over a wave.
  • arcs: Rotating quarter/half circles for a softer feel.
Inheritance
Available extensions

Values

dots → const SpinnerStyle

Braille-inspired glyphs with fluid motion.

bars → const SpinnerStyle

Rising bar graph that loops over a wave.

arcs → const SpinnerStyle

Rotating quarter/half circles for a softer feel.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
name String

Available on SpinnerStyle, provided by the SpinnerStyleExtensions extension

Returns a human-readable name for the spinner style.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SpinnerStyle>
A constant List of the values in this enum, in order of their declaration.