themed method
Returns a new client using the provided theme, preserving the terminal.
Implementation
Terminice themed(PromptTheme theme) {
return withTheme(theme);
}
Returns a new client using the provided theme, preserving the terminal.
Terminice themed(PromptTheme theme) {
return withTheme(theme);
}