TerminiceExecutionMode enum

The effective way a built-in Terminice component should execute.

Inheritance
Available extensions

Values

rich → const TerminiceExecutionMode

Full-screen or raw-key interaction on a capable terminal.

line → const TerminiceExecutionMode

Line-oriented interaction for a terminal with unsuitable output.

unattended → const TerminiceExecutionMode

Non-interactive execution that must not read from standard input.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TerminiceExecutionMode>
A constant List of the values in this enum, in order of their declaration.