ColumnConfig class

Configuration for a table column.

Constructors

ColumnConfig(String header, {ColumnAlign align = ColumnAlign.left, int? minWidth, int? maxWidth})
const
ColumnConfig.center(String header, {int? minWidth, int? maxWidth})
Creates a center-aligned column.
const
ColumnConfig.left(String header, {int? minWidth, int? maxWidth})
Creates a left-aligned column.
const
ColumnConfig.right(String header, {int? minWidth, int? maxWidth})
Creates a right-aligned column.
const

Properties

align ColumnAlign
Alignment of content in this column.
final
hashCode int
The hash code for this object.
no setterinherited
The header text for this column.
final
maxWidth int?
Maximum width for this column (optional).
final
minWidth int?
Minimum width for this column (optional).
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited