clearOnEnd property
Whether to clear the rendered output when the prompt ends. If false, the final render remains visible.
Implementation
final bool clearOnEnd;
Whether to clear the rendered output when the prompt ends. If false, the final render remains visible.
final bool clearOnEnd;