FormResult class

The confirmed result of a FormPrompt, containing all field values.

Access values by index:

final password = result[0];
final verify = result[1];

Constructors

FormResult(List<String> values)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Number of fields.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
The trimmed text values of each field, in order.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) String
Returns the value at index.