bottom method
Returns the bottom line sized to match the top.
Implementation
String bottom() {
return FrameRenderer.bottomLine(title, theme);
}
Returns the bottom line sized to match the top.
String bottom() {
return FrameRenderer.bottomLine(title, theme);
}