key static method
Wraps a keyboard label in square brackets with the proper accent color.
Implementation
static String key(String label, PromptTheme theme) {
return '[${theme.keyAccent}$label${theme.reset}]';
}
Wraps a keyboard label in square brackets with the proper accent color.
static String key(String label, PromptTheme theme) {
return '[${theme.keyAccent}$label${theme.reset}]';
}