add method
Adds a single binding to this collection.
Returns a new collection with binding appended to the end.
Implementation
KeyBindings add(KeyBinding binding) {
return KeyBindings([..._bindings, binding]);
}
Adds a single binding to this collection.
Returns a new collection with binding appended to the end.
KeyBindings add(KeyBinding binding) {
return KeyBindings([..._bindings, binding]);
}