addAll method
Adds multiple bindings to this collection.
Returns a new collection with every binding in bindings appended.
Implementation
KeyBindings addAll(List<KeyBinding> bindings) {
return KeyBindings([..._bindings, ...bindings]);
}
Adds multiple bindings to this collection.
Returns a new collection with every binding in bindings appended.
KeyBindings addAll(List<KeyBinding> bindings) {
return KeyBindings([..._bindings, ...bindings]);
}