char property
Printable character, or the lowercase letter that was combined with Ctrl
for ctrlGeneric events (e.g. ^A → a). Null for keys without a
character payload.
Implementation
final String? char;
Printable character, or the lowercase letter that was combined with Ctrl
for ctrlGeneric events (e.g. ^A → a). Null for keys without a
character payload.
final String? char;