ListViewport class

Viewport information for list rendering.

Contains the range of visible items and overflow indicators.

Constructors

ListViewport({required int start, required int end, required bool hasOverflowAbove, required bool hasOverflowBelow})
const

Properties

end int
Index after the last visible item (exclusive).
final
hashCode int
The hash code for this object.
no setterinherited
hasOverflowAbove bool
Whether there are hidden items above the viewport.
final
hasOverflowBelow bool
Whether there are hidden items below the viewport.
final
isEmpty bool
Whether the viewport is empty.
no setter
length int
Number of items in the viewport.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start int
Index of the first visible item.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited