SelectableListPromptBuilder<T> class
Builder for creating customized SelectableListPrompt instances.
Example:
final selected = SelectableListPromptBuilder<String>()
.title('Select items')
.items(myItems)
.multiSelect(true)
.maxVisible(8)
.withSelectAll()
.build()
.run(...);
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(
) → SelectableListPrompt< T> -
extraBindings(
KeyBindings bindings) → SelectableListPromptBuilder< T> -
initialSelection(
Set< int> selection) → SelectableListPromptBuilder<T> -
items(
List< T> items) → SelectableListPromptBuilder<T> -
maxVisible(
int value) → SelectableListPromptBuilder< T> -
multiSelect(
[bool value = true]) → SelectableListPromptBuilder< T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
reservedLines(
int lines) → SelectableListPromptBuilder< T> -
theme(
PromptTheme theme) → SelectableListPromptBuilder< T> -
title(
String title) → SelectableListPromptBuilder< T> -
toString(
) → String -
A string representation of this object.
inherited
-
withSelectAll(
{String hintDescription = 'select all / clear'}) → SelectableListPromptBuilder< T> - Adds 'A' key binding for select all / clear all.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited