CursorState class

Cursor state for text input prompts.

In sync mode, the cursor is always visible (no blinking). This class is kept for API compatibility.

Constructors

CursorState()
Creates a cursor state.

Properties

hashCode int
The hash code for this object.
no setterinherited
isVisible bool
Whether the cursor should be visible (always true in sync mode).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited