persist constant
EndBehavior
const persist
Keeps the final render visible after the prompt ends.
Implementation
static const EndBehavior persist = EndBehavior(clearOnEnd: false);
Keeps the final render visible after the prompt ends.
static const EndBehavior persist = EndBehavior(clearOnEnd: false);