FallbackFormResult class

Result returned by FallbackPrompt.form.

Constructors

FallbackFormResult(List<String> values)
Creates a fallback form result.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
length int
Number of accepted field values.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values List<String>
Accepted field values in declaration order.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) String
Returns the value at index.