FallbackRangeResult class

Result returned by FallbackPrompt.range.

Constructors

FallbackRangeResult({required num start, required num end})
Creates a range result with an ordered start and end.
const

Properties

end num
Ordered upper value for the accepted range.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start num
Ordered lower value for the accepted range.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited