GridLayout class
Layout information for a grid.
Constructors
Properties
- columns → int
-
Number of columns.
final
- focusedColumn → int
-
Currently focused column.
final
- focusedIndex → int
-
Currently focused item index.
final
- focusedRow → int
-
Currently focused row.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isEmpty → bool
-
Whether the grid is empty.
no setter
- itemCount → int
-
Total number of items.
final
- rows → int
-
Number of rows.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
indexAt(
int row, int col) → int - Index at a specific row and column (may exceed itemCount).
-
isValidIndex(
int index) → bool - Whether an index is within the item count.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited