KeyEventType enum

Normalized terminal key event types.

These cover common control keys, arrows, printable characters, and unknown bytes. Use with KeyEvent for prompt and view input handling.

Inheritance
Available extensions

Values

enter → const KeyEventType
esc → const KeyEventType
ctrlC → const KeyEventType
ctrlR → const KeyEventType
ctrlD → const KeyEventType
ctrlE → const KeyEventType
ctrlGeneric → const KeyEventType
tab → const KeyEventType
arrowUp → const KeyEventType
arrowDown → const KeyEventType
arrowLeft → const KeyEventType
arrowRight → const KeyEventType
backspace → const KeyEventType
space → const KeyEventType
slash → const KeyEventType
char → const KeyEventType
unknown → const KeyEventType

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KeyEventType>
A constant List of the values in this enum, in order of their declaration.