switchControlHighlighted method

String switchControlHighlighted(
  1. bool on, {
  2. bool highlight = false,
})

Returns a highlighted switch control (for focused items).

Wraps the switch control with inverse styling when highlight is true and the theme supports inverse highlighting.

Implementation

String switchControlHighlighted(bool on, {bool highlight = false}) {
  final base = switchControl(on);
  if (highlight && features.useInverseHighlight) {
    return '${theme.inverse}$base${theme.reset}';
  }
  return base;
}