setTerminalType method
Sets the terminal type used by automatic capability detection.
Implementation
void setTerminalType(String? value) {
_terminalType = value;
}
Sets the terminal type used by automatic capability detection.
void setTerminalType(String? value) {
_terminalType = value;
}