NormalizedNumericRange class

An ordered pair produced by normalizeSteppedRange.

Constructors

NormalizedNumericRange({required num start, required num end})
Creates an ordered normalized range.
const

Properties

end num
The normalized upper endpoint.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start num
The normalized lower endpoint.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited