RankResult class

Result of ranking an item.

Constructors

RankResult(int score, List<int> spans)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int
Score for sorting (higher = better match).
final
spans List<int>
Character indices that matched (for highlighting).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

noMatch → const RankResult?
No match result.