selection property
SelectionController
get
selection
Current selection state, using indices in the original items.
Implementation
SelectionController get selection => _selection;
Current selection state, using indices in the original items.
SelectionController get selection => _selection;