buildBindings property
Builds key bindings given the prompt state.
This allows bindings to reference and modify the state.
The state provides cancel method to mark as cancelled.
Implementation
final KeyBindings Function(PromptState<T> state) buildBindings;