StatTone enum

Tone for stat/styled items.

Used by style-aware components to resolve semantic colors through the active PromptTheme. Prefer using a tone instead of hard-coding colors so downstream themes can adapt.

Inheritance
Available extensions

Values

info → const StatTone

Informational state (maps to theme info color).

warn → const StatTone

Warning state (maps to theme warn color).

error → const StatTone

Error state (maps to theme error color).

accent → const StatTone

Accent state (maps to theme accent color).

success → const StatTone

Success state (maps to theme checkboxOn color).

neutral → const StatTone

Neutral state (maps to theme gray color).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StatTone>
A constant List of the values in this enum, in order of their declaration.