TerminalScript class

Immutable, reusable terminal input queued for a MockTerminal.

Constructors

TerminalScript(Iterable<TerminalScriptStep> steps)
Creates a script from already-built steps.
TerminalScript.build(void build(TerminalScriptBuilder script))
Creates a script with the fluent TerminalScriptBuilder.
factory
TerminalScript.lines(Iterable<String> lines)
Creates a script that queues each line for MockTerminalInput.readLineSync.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Whether this script has no queued input.
no setter
isNotEmpty bool
Whether this script has at least one queued input step.
no setter
length int
Number of queued input steps.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<TerminalScriptStep>
Input operations in queue order.
final

Methods

applyToInput(MockTerminalInput input) → void
Queues this script on input.
applyToTerminal(MockTerminal terminal) → void
Queues this script on terminal.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited