isNotEmpty property
bool
get
isNotEmpty
Whether this script has at least one queued input step.
Implementation
bool get isNotEmpty => steps.isNotEmpty;
Whether this script has at least one queued input step.
bool get isNotEmpty => steps.isNotEmpty;