setText method
Sets the buffer to new text, cursor at end.
Implementation
void setText(String newText) {
final value = _truncate(newText, maxLength ?? newText.length);
_replace(value, value.length);
}
Sets the buffer to new text, cursor at end.
void setText(String newText) {
final value = _truncate(newText, maxLength ?? newText.length);
_replace(value, value.length);
}