TreeNavigationHelper<T> mixin
Helper for tree-like hierarchical navigation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
buildTreeEntries<
E> ({required List< T> roots, required bool isExpanded(T node), required List<T> getChildren(T node), required E createEntry(T node, int depth, bool isLast, List<bool> ancestorLines)}) → List<E> - Builds visible entries from a tree structure.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited