FlowContext class
Read-only view of values collected by earlier flow steps.
Properties
Methods
-
contains(
String key) → bool -
Whether
keyhas been written by the flow.inherited -
fallbackPromptTitle(
String title) → String -
Returns the plain
titlefor fallback or basic prompt text. -
flag(
String key) → bool -
Returns the boolean flag stored for
key.inherited -
list<
T> (String key) → List< T> -
Returns the list stored for
keyasList<T>.inherited -
maybe<
T> (String key) → T? -
Returns the value stored for
keyasT, ornullwhen absent or null.inherited -
maybeFlag(
String key) → bool? -
Returns the boolean flag stored for
key, ornullwhen absent or null.inherited -
maybeString(
String key) → String? -
Returns the string stored for
key, ornullwhen absent or null.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
promptTitle(
String title) → String -
Returns
titledecorated with the current flow progress when enabled. -
runComponent<
T> (TerminiceComponent< T> component) → T -
Runs
componentwith the Terminice instance configured for this flow. -
string(
String key) → String -
Returns the string stored for
key.inherited -
toMap(
) → Map< String, Object?> -
Returns an insertion-ordered copy of the visible values.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
value<
T> (String key) → T -
Returns the value stored for
keyasT.inherited -
valueOr<
T> (String key, T fallback) → T -
Returns the value stored for
keyasT, orfallbackwhen absent/null.inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited