prepareFrame method
Prepares a RenderOutput, clears the previous frame if one was drawn, and returns the output for the subclass to render into.
Implementation
RenderOutput prepareFrame() {
_output ??= RenderOutput();
final out = _output!;
if (_started) out.clear();
_started = true;
return out;
}