TerminiceFallbackMode enum
Policy for choosing built-in rich, line-oriented, or unattended execution.
Values
- interactive → const TerminiceFallbackMode
-
Always use the existing rich, interactive prompt implementations.
- auto → const TerminiceFallbackMode
-
Automatically select rich, line-oriented, or unattended execution.
- fallback → const TerminiceFallbackMode
-
Always use line-mode fallback for built-in components.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
executionModeFor(
Terminal terminal, {String? term}) → TerminiceExecutionMode -
Resolves the effective execution mode for
terminal. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shouldUseFallback(
Terminal terminal) → bool - Whether this mode uses the compatibility line-mode fallback view.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TerminiceFallbackMode> - A constant List of the values in this enum, in order of their declaration.