DiscreteValuePrompt class
DiscreteValuePrompt – for discrete value selection (ratings, stars).
Constructors
- DiscreteValuePrompt({required String title, int maxValue = 5, int initial = 3, PromptTheme theme = PromptTheme.dark})
Properties
- bindings → KeyBindings
-
Current key bindings.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- initial → int
-
Initial value.
final
- maxValue → int
-
Maximum value (1 to maxValue).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → PromptTheme
-
Theme for styling.
final
- title → String
-
Title for the frame header.
final
- value → int
-
Current value.
no setter
- wasCancelled → bool
-
Whether the prompt was cancelled.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
{required void render(FrameContext ctx, int value, int maxValue), KeyBindings? extraBindings}) → int - Runs the discrete value prompt.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited