KeyActionResult enum
Result of a key action handler.
handled: Key was processed, continue the loop (re-render)confirmed: End prompt with confirmed resultcancelled: End prompt with cancelled resultignored: Key was not handled by this binding
Values
- handled → const KeyActionResult
-
Key was handled, continue the prompt loop (trigger re-render)
- confirmed → const KeyActionResult
-
End prompt with confirmed result
- cancelled → const KeyActionResult
-
End prompt with cancelled result
- ignored → const KeyActionResult
-
Key was not handled by this binding (try next binding)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
KeyActionResult> - A constant List of the values in this enum, in order of their declaration.