tabSwitch static method
Creates Tab binding for switching between items/modes.
Alias for tab that reads nicer in contexts where the intent is to swap focus rather than perform a generic tab action.
Implementation
static KeyBindings tabSwitch({
required void Function() onTab,
String hintLabel = 'Tab',
String hintDescription = 'switch',
}) {
return tab(
onTab: onTab, hintLabel: hintLabel, hintDescription: hintDescription);
}