RangeValuePrompt class
RangeValuePrompt – for selecting a range with two handles.
Constructors
- RangeValuePrompt({required String title, num min = 0, num max = 100, num startInitial = 20, num endInitial = 80, num step = 1, PromptTheme theme = PromptTheme.dark})
Properties
- bindings → KeyBindings
-
Current key bindings.
no setter
- editingStart → bool
-
Whether currently editing start (vs end).
no setter
- end → num
-
Current end value.
no setter
- endInitial → num
-
Initial end value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- max → num
-
Maximum value.
final
- min → num
-
Minimum value.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → num
-
Current start value.
no setter
- startInitial → num
-
Initial start value.
final
- step → num
-
Step size for adjustments.
final
- theme → PromptTheme
-
Theme for styling.
final
- title → String
-
Title for the frame header.
final
- wasCancelled → bool
-
Whether the prompt was cancelled.
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
run(
{required void render(FrameContext ctx, num start, num end, bool editingStart), KeyBindings? extraBindings}) → RangeResult - Runs the range value prompt.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited