SyncPrompts class
Factory methods for common sync prompt patterns.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
password(
{required String title, bool required = true, bool allowReveal = true, String maskChar = '•', PromptTheme theme = PromptTheme.dark}) → TextPromptSync - Creates a password input prompt with masking.
-
text(
{required String title, String? placeholder, String? validator(String text)?, bool required = false, PromptTheme theme = PromptTheme.dark}) → TextPromptSync - Creates a text input prompt with optional validation.
-
validated(
{required String title, required String? validator(String), String? placeholder, PromptTheme theme = PromptTheme.dark}) → TextPromptSync - Creates a text input with custom validation message.