SyntaxHighlighter class
SyntaxHighlighter – theme-aware syntax highlighting utilities.
Use for highlighting code snippets within framed content.
Constructors
- SyntaxHighlighter(PromptTheme theme)
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- theme → PromptTheme
-
final
Methods
-
autoLine(
String line) → String - Auto-detects language and highlights.
-
dartLine(
String line) → String - Highlights a line of Dart code.
-
jsonLine(
String line) → String - Highlights a line of JSON.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
shellLine(
String line) → String - Highlights a line of shell/bash.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited