ListWindow<T> class
A window of visible items from a list.
Contains the actual items plus metadata for rendering.
Constructors
Properties
- end → int
-
Index after the last visible item (exclusive) in the original list.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasOverflowAbove → bool
-
Whether there are hidden items above the viewport.
final
- hasOverflowBelow → bool
-
Whether there are hidden items below the viewport.
final
- isEmpty → bool
-
Whether the window is empty.
no setter
- isNotEmpty → bool
-
Whether the window is not empty.
no setter
-
items
→ List<
T> -
The visible items (sublist of the original list).
final
- length → int
-
Number of items in the window.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- start → int
-
Index of the first visible item in the original list.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited