TerminalScriptStep class
One reusable queued-input operation in a TerminalScript.
Constructors
- TerminalScriptStep.key(KeyEventType key, [String? char])
-
Creates a step that queues
keythrough MockTerminalInput.queueKey.const - TerminalScriptStep.line(String text)
-
Creates a step that queues
textfor line-mode input.const - TerminalScriptStep.text(String text)
-
Creates a step that queues
textas UTF-8 raw input bytes.const
Properties
- char → String?
-
Optional character payload for character and generic Ctrl key events.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- key → KeyEventType?
-
Key payload for TerminalScriptStepKind.key steps.
final
- kind → TerminalScriptStepKind
-
The kind of input operation this step performs.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Text payload for TerminalScriptStepKind.line and
TerminalScriptStepKind.text steps.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queueOn(
MockTerminalInput input) → void -
Queues this step on
input. -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override